/*
 * libkedri.c - Kedrigern (Milena TTS server for Raspberry Pi)
 * Copyright (C) Bohdan R. Rau 2019 <ethanak@polip.com>
 *
 * Kedrigern is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * Kedrigern is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Kedrigern.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#include "kedrigern.h"
#include <sys/socket.h>
#include <arpa/inet.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

static char *sendSocket(char *str, struct kdr_Voice *k)
{
    int sockfd;static char buf[16];
    struct sockaddr_in servaddr; 

    sockfd = socket(AF_INET, SOCK_STREAM, 0); 
    if (sockfd == -1) { 
        perror("Socket");
        return NULL;
    } 
    bzero(&servaddr, sizeof(servaddr)); 
    servaddr.sin_family = AF_INET; 
    servaddr.sin_addr.s_addr = inet_addr(k ? k->ip : "127.0.0.1"); 
    servaddr.sin_port = htons(k ? k->port : 1314); 
    if (connect(sockfd, (struct sockaddr *)&servaddr, sizeof(servaddr)) != 0) {
        perror("connect");
        close(sockfd);
        return NULL;
    }
    send(sockfd, str, strlen(str), 0);
    int n = recv(sockfd, buf, 16, 0);
    close(sockfd);
    if (n) return buf;
    return NULL;
}

struct kdr_Voice *kdr_InitVoice(struct kdr_Voice *k)
{
    if (!k) k = malloc(sizeof(*k));
    k->freq = 1.0;
    k->tempo = 1.0;
    k->samplefreq = 16000;
    k->samplerate = 16000;
    strcpy(k->ip,"127.0.0.1");
    k->port=1314;
    k->flags = 0;
    return k;
}

int kdr_Say(char *text, struct kdr_Voice *k)
{
    if (!*text) return 0;
    char buf[strlen(text)+64];
    strcpy(buf,"speak ");
    char *c=buf+strlen(buf);
    if (k) {
        if (k->tempo != 1.0) c += sprintf(c,"-t %.2f ", k->tempo);
        if (k->freq != 1.0) c += sprintf(c,"-f %.2f ", k->freq);
        if (k->samplefreq != 16000) c += sprintf(c,"-l %d ", k->samplefreq);
        if (k->samplerate != 16000) c += sprintf(c,"-r %d ", k->samplerate);
    }
    strcpy(c,text);
    c+=strlen(c)-1;
    c=sendSocket(buf, k);
    if (c && !strcmp(c,"OK")) return 0;
    return -1;
}

int kdr_Stop(struct kdr_Voice *k)
{
    char *c = sendSocket("stop",k);
    return (c && !strcmp(c,"OK")?0:1);
}

int kdr_IsSpeaking(struct kdr_Voice *k)
{
    char *c = sendSocket("status",k);
    return !c ? -1 : !strcmp(c,"idle") ? 1 : 0;
}
